package com.chelvc.cloud.vehicle.api.param;

import com.chelvc.framework.common.model.File;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import javax.validation.constraints.*;
import java.io.Serializable;
import java.util.List;

/**
 * 商家数据模型
 *
 * @author xp
 * @data 2023/4/10
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class MerchantModifyParam implements Serializable {
    /**
     * 商家名称
     */
    @NotEmpty(message = "商家名称不能为空")
    @Size(max = 100, message = "商家名称长度不能大于100")
    private String name;

    /**
     * 商家Logo
     */
    @Size(max = 200, message = "商家Logo长度不能大于200")
    private String logo;

    /**
     * 轮播图列表
     */
    private List<File> banners;

    /**
     * 联系人
     */
    @NotEmpty(message = "联系人不能为空")
    @Size(max = 50, message = "联系人长度不能大于50")
    private String liaison;

    /**
     * 联系电话
     */
    @NotEmpty(message = "联系电话不能为空")
    @Size(max = 50, message = "联系电话长度不能大于50")
    private String mobile;

    /**
     * 营业时间
     */
    @NotEmpty(message = "营业时间不能为空")
    @Size(max = 50, message = "营业时间长度不能大于50")
    private String opening;

    /**
     * 详细地址
     */
    @NotEmpty(message = "详细地址不能为空")
    @Size(max = 200, message = "营业时间长度不能大于200")
    private String address;

    /**
     * 所属地区
     */
    @NotNull(message = "所属地区不能为空")
    @Min(value = 100000, message = "所属地区不能小于100000")
    @Max(value = 999999, message = "所属地区不能大于999999")
    private Integer region;

    /**
     * 省
     */
    @NotNull(message = "所属省份不能为空")
    @Min(value = 100000, message = "所属省份不能小于100000")
    @Max(value = 999999, message = "所属省份不能大于999999")
    private Integer province;

    /**
     * 市
     */
    @NotNull(message = "所属城市不能为空")
    @Min(value = 100000, message = "所属城市不能小于100000")
    @Max(value = 999999, message = "所属城市不能大于999999")
    private Integer city;

    /**
     * 区
     */
    @NotNull(message = "所在地区不能为空")
    @Min(value = 100000, message = "所属区不能小于100000")
    @Max(value = 999999, message = "所属区不能大于999999")
    private Integer district;

    /**
     * 经度
     */
    @NotNull(message = "经度不能为空")
    private Double longitude;

    /**
     * 纬度
     */
    @NotNull(message = "纬度不能为空")
    private Double latitude;

    /**
     * 是否推荐
     */
    @NotNull(message = "是否推荐不能为空")
    private Boolean recommend;

    /**
     * 商家主营业务
     */
    private List<Long> mainBusiness;
    /**
     * 商家副营业务
     */
    private List<Long> ancillaryBusiness;

    /**
     * 营业状态 0-营业中 1-休息中
     */
    private String businessStatus;
}
