package com.chelvc.cloud.vehicle.server.service.impl;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.api.dto.FeedBackDTO;
import com.chelvc.cloud.vehicle.api.param.FeedBackModifyParam;
import com.chelvc.cloud.vehicle.api.param.FeedBackPagingParam;
import com.chelvc.cloud.vehicle.server.copier.FeedbackCopier;
import com.chelvc.cloud.vehicle.server.dao.FeedbackMapper;
import com.chelvc.cloud.vehicle.server.entity.FeedBack;
import com.chelvc.cloud.vehicle.server.service.FeedbackService;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.util.AssertUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.database.context.DatabaseContextHolder;
import lombok.NonNull;
import org.apache.dubbo.config.annotation.DubboService;

import java.util.Date;
import java.util.List;

/**
 * 意见反馈业务操作实现
 *
 * @author liude
 * @date 2024/1/16
 */
@DubboService(interfaceClass = com.chelvc.cloud.vehicle.api.service.FeedbackService.class)
public class FeedbackServiceImpl extends ServiceImpl<FeedbackMapper, FeedBack> implements FeedbackService,
        com.chelvc.cloud.vehicle.api.service.FeedbackService {
    @Override
    public Long addFeedback(@NonNull FeedBackModifyParam param) {
        FeedBack feedBack = FeedbackCopier.INSTANCE.copying(param);
        Long userId = SessionContextHolder.getId();
        feedBack.setCreateTime(new Date());
        feedBack.setUserId(userId);
        feedBack.setStatus("1");
        this.save(feedBack);
        return feedBack.getId();
    }

    @Override
    public void updateFeedback(@NonNull Long id, @NonNull FeedBackModifyParam param) {
        FeedBack feedBack = AssertUtils.available(this.getById(id), "该意见反馈不存在");
        FeedbackCopier.INSTANCE.copying(param, feedBack);
        this.updateById(feedBack);
    }
    @Override
    public List<FeedBackDTO> getFeedback(@NonNull String channel){
        Long userId = SessionContextHolder.getId();
        List<FeedBack> feedBack = this.lambdaQuery()
                .eq(FeedBack::getUserId, userId)
                .eq(FeedBack::getChannel,channel)
                .orderByDesc(FeedBack::getCreateTime)
                .list();
        return FeedbackCopier.INSTANCE.copying(feedBack);
    }

    @Override
    public Pagination<FeedBackDTO> getFeedbackPaging(FeedBackPagingParam param){
        Page<FeedBack> page = this.lambdaQuery()
                .eq(StringUtils.notEmpty(param.getStatus()),FeedBack::getStatus,param.getStatus())
                .like(StringUtils.notEmpty(param.getTitle()),FeedBack::getTitle,param.getTitle())
                .eq(StringUtils.notEmpty(param.getChannel()),FeedBack::getChannel,param.getChannel())
                .orderByDesc(FeedBack::getCreateTime)
                .page(DatabaseContextHolder.page(param.getPaging()));

        return DatabaseContextHolder.pagination(page,FeedbackCopier.INSTANCE::copying);
    }
    @Override
    public void updateStatus(Long id,String status){
        FeedBack feedBack = AssertUtils.available(this.getById(id), "该意见反馈不存在");
        feedBack.setStatus(status);
        this.updateById(feedBack);
    }

 }
