package com.chelvc.cloud.vehicle.server.service.impl;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.api.dto.MerchantCartItemDTO;
import com.chelvc.cloud.vehicle.api.dto.OmsCartItemDTO;
import com.chelvc.cloud.vehicle.api.param.OmsCartItemModifyParam;
import com.chelvc.cloud.vehicle.server.copier.CartItemCopier;
import com.chelvc.cloud.vehicle.server.copier.MerchantCopier;
import com.chelvc.cloud.vehicle.server.dao.OmsCartItemMapper;
import com.chelvc.cloud.vehicle.server.entity.Merchant;
import com.chelvc.cloud.vehicle.server.entity.OmsCartItem;
import com.chelvc.cloud.vehicle.server.service.MerchantService;
import com.chelvc.cloud.vehicle.server.service.OmsCartItemService;
import com.chelvc.framework.base.context.SessionContextHolder;
import lombok.RequiredArgsConstructor;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.dubbo.config.annotation.DubboService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;

import java.util.Date;
import java.util.List;

/**
 * 购物车Service业务层处理
 * 
 * @author liude
 * @date 2023-11-08
 */
@RequiredArgsConstructor(onConstructor = @__({@Autowired, @Lazy}))
@DubboService(interfaceClass = com.chelvc.cloud.vehicle.api.service.OmsCartItemService.class)
public class OmsCartItemServiceImpl extends ServiceImpl<OmsCartItemMapper, OmsCartItem> implements OmsCartItemService,
        com.chelvc.cloud.vehicle.api.service.OmsCartItemService {

    private final MerchantService merchantService;

    @Override
    public int add(OmsCartItemModifyParam cartItem) {
        int count;
        Long userId = SessionContextHolder.getId();
        OmsCartItem omsCartItem = CartItemCopier.INSTANCE.copying(cartItem);
        omsCartItem.setUserId(userId);
        omsCartItem.setMemberNickname(userId.toString());
        omsCartItem.setDeleteStatus(0);
        OmsCartItem existCartItem = getCartItem(omsCartItem);
        if (existCartItem == null) {
            omsCartItem.setCreateTime(new Date());
            count = this.baseMapper.insert(omsCartItem);
        } else {
            existCartItem.setUpdateTime(new Date());
            existCartItem.setQuantity(existCartItem.getQuantity() + cartItem.getQuantity());
            count = this.baseMapper.updateById(existCartItem);
        }
        return count;
    }

    /**
     * 根据会员id,商品id和规格获取购物车中商品
     */
    private OmsCartItem getCartItem(OmsCartItem cartItem) {
        List<OmsCartItem> cartItemList = this.lambdaQuery()
                .eq(OmsCartItem::getUserId, cartItem.getUserId())
                .eq(OmsCartItem::getGoodsId, cartItem.getGoodsId())
                .eq(OmsCartItem::getDeleteStatus,0)
                .eq(OmsCartItem::getMerchantId, cartItem.getMerchantId()).list();
        if (!CollectionUtils.isEmpty(cartItemList)) {
            return cartItemList.get(0);
        }
        return null;
    }

    @Override
    public List<OmsCartItemDTO> listCartItem() {
        Long userId = SessionContextHolder.getId();
        OmsCartItem omsCartItem = new OmsCartItem();
        omsCartItem.setUserId(userId);
        List<OmsCartItem> cartItemList = this.lambdaQuery()
                .eq(OmsCartItem::getUserId, userId).list();
        return CartItemCopier.INSTANCE.copying(cartItemList);
    }

    public List<OmsCartItemDTO> listCartItem(List<Long> cartIds) {
        Long userId = SessionContextHolder.getId();
        OmsCartItem omsCartItem = new OmsCartItem();
        omsCartItem.setUserId(userId);
        List<OmsCartItem> cartItemList = this.lambdaQuery()
                .eq(OmsCartItem::getUserId, userId)
                .eq(OmsCartItem::getDeleteStatus,0)
                .in(OmsCartItem::getGoodsId,cartIds).list();
        return CartItemCopier.INSTANCE.copying(cartItemList);
    }

    @Override
    public List<OmsCartItemDTO> listPromotion(List<Long> cartIds) {
        if (CollectionUtils.isEmpty(cartIds)) {
            return null;
        }
        return listCartItem(cartIds);
//        List<CartPromotionItemDTO> cartPromotionItemList = new ArrayList<>();
//        if (!CollectionUtils.isEmpty(cartItemList)) {
//            cartPromotionItemList.add(cartItemList);
//            cartPromotionItemList = promotionService.calcCartPromotion(cartItemList);
//        }
//        return cartItemList;
    }

    @Override
    public int updateQuantity(Long id, Integer quantity) {
        Long userId = SessionContextHolder.getId();
        OmsCartItem cartItem = this.lambdaQuery()
                .eq(OmsCartItem::getUserId, userId).eq(
                        OmsCartItem::getId, id
                ).one();
        cartItem.setQuantity(quantity);
        cartItem.setDeleteStatus(0);
        return this.baseMapper.updateById(cartItem);
    }

    @Override
    public void delete(List<Long> ids) {
        Long userId = SessionContextHolder.getId();
        delete(ids, userId);
    }

    @Override
    public void delete(List<Long> ids,Long userId) {
        for (Long id : ids) {
            OmsCartItem cartItem = this.lambdaQuery()
                    .eq(OmsCartItem::getUserId, userId).eq(
                            OmsCartItem::getId, id
                    ).one();
            if (cartItem != null){
                cartItem.setDeleteStatus(1);
                this.baseMapper.updateById(cartItem);
            }
        }
    }

//    @Override
//    public CartProduct getCartProduct(Long productId) {
//        return productDao.getCartProduct(productId);
//    }

    @Override
    public int updateAttr(OmsCartItemModifyParam cartItem) {
        //删除原购物车信息
        OmsCartItem updateCart = new OmsCartItem();
        updateCart.setId(cartItem.getId());
        updateCart.setUpdateTime(new Date());
        updateCart.setDeleteStatus(1);
        this.baseMapper.updateById(updateCart);
        cartItem.setId(null);
        add(cartItem);
        return 1;
    }

    @Override
    public void clear() {
        Long userId = SessionContextHolder.getId();
        List<OmsCartItem> cartItemList = this.lambdaQuery()
                .eq(OmsCartItem::getUserId, userId).list();
        for (OmsCartItem omsCartItem : cartItemList) {
            omsCartItem.setDeleteStatus(1);
            this.baseMapper.updateById(omsCartItem);
        }
    }


    @Override
    public MerchantCartItemDTO listCartItem(Long merchantId) {
        Long userId = SessionContextHolder.getId();
        OmsCartItem omsCartItem = new OmsCartItem();
        omsCartItem.setUserId(userId);
        List<OmsCartItem> cartItemList = this.lambdaQuery()
                .eq(OmsCartItem::getUserId, userId)
                .eq(OmsCartItem :: getMerchantId,merchantId)
                .eq(OmsCartItem::getDeleteStatus,"0").list();
        List<OmsCartItemDTO> omsCartItemList = CartItemCopier.INSTANCE.copying(cartItemList);
        Merchant merchant = merchantService.getById(merchantId);
        MerchantCartItemDTO merchantCartItemDTO = new MerchantCartItemDTO();
        merchantCartItemDTO.setCartItems(omsCartItemList);
        merchantCartItemDTO.setMerchantDTO(MerchantCopier.INSTANCE.copying(merchant));
        return merchantCartItemDTO;
    }

    public List<OmsCartItemDTO> merchantListCartItem(Long merchantId){
        Long userId = SessionContextHolder.getId();
        List<OmsCartItem> cartItemList = this.lambdaQuery()
                .eq(OmsCartItem::getUserId, userId)
                .eq(OmsCartItem::getDeleteStatus,0)
                .eq(OmsCartItem::getMerchantId,merchantId)
                .list();
        return CartItemCopier.INSTANCE.copying(cartItemList);
    }


//    @Override
//    public List<MerchantCartItemDTO> listCartItemByUserId() {
//        Long userId = SessionContextHolder.getId();
//        OmsCartItem omsCartItem = new OmsCartItem();
//        omsCartItem.setUserId(userId);
//        List<OmsCartItem> cartItemList = this.lambdaQuery()
//                .eq(OmsCartItem::getUserId, userId)
//                .eq(OmsCartItem::getDeleteStatus,"0")
//                .orderByDesc(OmsCartItem::getCreateTime).list();
//        List<OmsCartItemDTO> omsCartItemList = CartItemCopier.INSTANCE.copying(cartItemList);
//        if (!omsCartItemList.isEmpty() && omsCartItemList.size() > 0){
//            Merchant merchant = this.merchantService.getById(merchantId);
//            MerchantCartItemDTO merchantCartItemDTO = new MerchantCartItemDTO();
//            merchantCartItemDTO.setCartItems(omsCartItemList);
//            merchantCartItemDTO.setMerchantDTO(MerchantCopier.INSTANCE.copying(merchant));
//        }
//
//        return merchantCartItemDTO;
//    }
}
